==> haskell-hookup-0.8-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hookup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hookup
version:              0.8
visibility:           public
id:                   hookup-0.8-9fuScXvgeNV1HoEKZHQfOI
key:                  hookup-0.8-9fuScXvgeNV1HoEKZHQfOI
license:              ISC
copyright:            2016-2020 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:
    Abstraction over creating network connections with SOCKS5 and TLS

description:
    This package provides an abstraction for communicating with line-oriented
    network services while abstracting over the use of SOCKS5 and TLS (via OpenSSL)

category:             Network
abi:                  a1842a6fc9fb31223e22381269fa21df
exposed:              True
exposed-modules:      Hookup Hookup.OpenSSL
hidden-modules:       Hookup.Socks5 Hookup.Concurrent
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hookup-0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hookup-0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hookup-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hookup
hs-libraries:         HShookup-0.8-9fuScXvgeNV1HoEKZHQfOI
depends:
    HsOpenSSL-0.11.7.9-AojKwhvEWDdFvrcG1JWLeX
    HsOpenSSL-x509-system-0.1.0.4-6AHFA7ALOvYEjiHDZAGcxG
    async-2.2.5-13mgd2n56qe7oct6GfBbZY
    attoparsec-0.14.4-2LtDsLmLe3yKhxR8c5Iii0 base-4.17.2.1
    bytestring-0.11.5.3 network-3.1.4.0-HEqaUi724nxGs7WtLdNH8M
    stm-2.5.1.0

haddock-interfaces:   /usr/share/doc/haskell-hookup/html/hookup.haddock
haddock-html:         /usr/share/doc/haskell-hookup/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hookup-0.8-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hookup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hookup
version:              0.8
visibility:           public
id:                   hookup-0.8-AZO4HRYyebyH7UbHnGM0J4
key:                  hookup-0.8-AZO4HRYyebyH7UbHnGM0J4
license:              ISC
copyright:            2016-2020 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:
    Abstraction over creating network connections with SOCKS5 and TLS

description:
    This package provides an abstraction for communicating with line-oriented
    network services while abstracting over the use of SOCKS5 and TLS (via OpenSSL)

category:             Network
abi:                  2797b7e623ad80bbdf56131404fd5a52
exposed:              True
exposed-modules:      Hookup Hookup.OpenSSL
hidden-modules:       Hookup.Socks5 Hookup.Concurrent
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hookup-0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hookup-0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hookup-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hookup
hs-libraries:         HShookup-0.8-AZO4HRYyebyH7UbHnGM0J4
depends:
    HsOpenSSL-0.11.7.9-4EtY31C2W0ZVQ6xRTjnnF
    HsOpenSSL-x509-system-0.1.0.4-8dWN41ryN9l1lmJwTQHpIF
    async-2.2.5-5zadbbqeCp9HahDgxNyESl
    attoparsec-0.14.4-CZt0qAnGZHQHCYZEsndAye base-4.17.2.1
    bytestring-0.11.5.3 network-3.1.4.0-GjkG889aAvvIfieaCEFwUy
    stm-2.5.1.0

haddock-interfaces:   /usr/share/doc/haskell-hookup/html/hookup.haddock
haddock-html:         /usr/share/doc/haskell-hookup/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
